@@ -20,7 +20,7 @@ import traceback
 from twisted.internet.interfaces import (
     IReactorCore, IReactorTime, IReactorThreads, IResolverSimple,
     IReactorPluggableResolver, IReactorPluggableNameResolver, IConnector,
-    IDelayedCall,
+    IDelayedCall, _ISupportsExitSignalCapturing
 )
 
 from twisted.internet import fdesc, main, error, abstract, defer, threads
@@ -47,7 +47,7 @@ class DelayedCall:
     # enable .debug to record creator call stack, and it will be logged if
     # an exception occurs while the function is being run
     debug = False
-    _str = None
+    _repr = None
 
     def __init__(self, time, func, args, kw, cancel, reset,
                  seconds=runtimeSeconds):
@@ -101,7 +101,7 @@ class DelayedCall:
             self.canceller(self)
             self.cancelled = 1
             if self.debug:
-                self._str = bytes(self)
+                self._repr = repr(self)
             del self.func, self.args, self.kw
 
     def reset(self, secondsFromNow):
@@ -181,9 +181,15 @@ class DelayedCall:
         return self.time < other.time
 
 
-    def __str__(self):
-        if self._str is not None:
-            return self._str
+    def __repr__(self):
+        """
+        Implement C{repr()} for L{DelayedCall} instances.
+
+        @rtype: C{str}
+        @returns: String containing details of the L{DelayedCall}.
+        """
+        if self._repr is not None:
+            return self._repr
         if hasattr(self, 'func'):
             # This code should be replaced by a utility function in reflect;
             # see ticket #6066:
@@ -445,7 +451,7 @@ class _ThreePhaseEvent(object):
 
 
 @implementer(IReactorCore, IReactorTime, IReactorPluggableResolver,
-             IReactorPluggableNameResolver)
+             IReactorPluggableNameResolver, _ISupportsExitSignalCapturing)
 class ReactorBase(object):
     """
     Default base class for Reactors.
@@ -473,6 +479,8 @@ class ReactorBase(object):
     @ivar _registerAsIOThread: A flag controlling whether the reactor will
         register the thread it is running in as the I/O thread when it starts.
         If C{True}, registration will be done, otherwise it will not be.
+
+    @ivar _exitSignal: See L{_ISupportsExitSignalCapturing._exitSignal}
     """
 
     _registerAsIOThread = True
@@ -481,6 +489,7 @@ class ReactorBase(object):
     installed = False
     usingThreads = False
     resolver = BlockingResolver()
+    _exitSignal = None
 
     __name__ = "twisted.internet.reactor"
 
@@ -644,22 +653,37 @@ class ReactorBase(object):
             'during', 'startup', self._reallyStartRunning)
 
     def sigInt(self, *args):
-        """Handle a SIGINT interrupt.
+        """
+        Handle a SIGINT interrupt.
+
+        @param args: See handler specification in L{signal.signal}
         """
         log.msg("Received SIGINT, shutting down.")
         self.callFromThread(self.stop)
+        self._exitSignal = args[0]
+
 
     def sigBreak(self, *args):
-        """Handle a SIGBREAK interrupt.
+        """
+        Handle a SIGBREAK interrupt.
+
+        @param args: See handler specification in L{signal.signal}
         """
         log.msg("Received SIGBREAK, shutting down.")
         self.callFromThread(self.stop)
+        self._exitSignal = args[0]
+
 
     def sigTerm(self, *args):
-        """Handle a SIGTERM interrupt.
+        """
+        Handle a SIGTERM interrupt.
+
+        @param args: See handler specification in L{signal.signal}
         """
         log.msg("Received SIGTERM, shutting down.")
         self.callFromThread(self.stop)
+        self._exitSignal = args[0]
+
 
     def disconnectAll(self):
         """Disconnect every reader, and writer in the system.
